/**
 * @file
 * This JavaScript file contains a Drupal behavior for initializing and managing
 * a Flickr slider with Slick carousel plugin. It also includes functionality
 * for displaying images in full screen on click and closing them with various
 * methods.
 */
(function ($, Drupal) {
  Drupal.behaviors.flickerSlider = {
    attach(context, settings) {
      $('.flickr-slider').each(function () {
        const id = $(this).attr('id');

        // Initializes the main image slider using Slick carousel plugin.
        $(`#${id} .slider-for:not(.slick-slider)`).slick({
          slidesToShow: 1,
          slidesToScroll: 1,
          arrows: false,
          fade: true,
          asNavFor: `#${id} .slider-nav`,
          adaptiveHeight: true,
          responsive: [
            {
              breakpoint: 768,
              settings: {
                adaptiveHeight: false,
              },
            },
          ],
        });

        // Initializes the thumbnail slider using Slick carousel plugin.
        $(`#${id} .slider-nav:not(.slick-slider)`).slick({
          slidesToShow: 3,
          slidesToScroll: 1,
          asNavFor: `#${id} .slider-for`,
          dots: false,
          centerMode: false,
          focusOnSelect: true,
          responsive: [
            {
              breakpoint: 768,
              settings: {
                slidesToShow: 3,
              },
            },
            {
              breakpoint: 480,
              settings: {
                slidesToShow: 1,
              },
            },
          ],
        });
      });

      // Open image in full screen on click
      $('.flickr-slider').on(
        'click',
        '.slider-for .slick-slide img',
        function () {
          const imgUrl = $(this).attr('src');
          const imgAlt = $(this).attr('alt');
          const fullScreenImage =
            `<div class="full-screen-image">` +
            `<span class="close-btn">&times;</span>` +
            `<span class="prev-btn">&lt;</span>` +
            `<span class="next-btn">&gt;</span>` +
            `<img src="${imgUrl}" alt="${imgAlt}">` +
            `</div>`;
          $('body').append(fullScreenImage);
          $('.full-screen-image').fadeIn();
        },
      );

      // Close full-screen image on clicking close button
      $(document).on('click', '.full-screen-image .close-btn', function () {
        $('.full-screen-image').fadeOut(function () {
          $(this).remove();
        });
      });

      // Close full-screen image on Escape key press
      $(document).on('keydown', function (e) {
        if (e.key === 'Escape') {
          $('.full-screen-image').fadeOut(function () {
            $(this).remove();
          });
        }
      });
    },
  };
})(jQuery, Drupal);
